==> js-0.15.0.tgz: package/src/plugins/auctionHouseModule/operations/loadPurchase.ts <==
import type { Commitment } from '@safecoin/web3.js';
import type { Metaplex } from '@/Metaplex';
import { useOperation, Operation, OperationHandler, amount } from '@/types';
import { DisposableScope } from '@/utils';
import { Purchase, LazyPurchase } from '../models/Purchase';
import { assertNftOrSftWithToken } from '../../nftModule';

// -----------------
// Operation
// -----------------

const Key = 'LoadPurchaseOperation' as const;

/**
 * @group Operations
 * @category Constructors
 */
export const loadPurchaseOperation = useOperation<LoadPurchaseOperation>(Key);

/**
 * @group Operations
 * @category Types
 */
export type LoadPurchaseOperation = Operation<
  typeof Key,
  LoadPurchaseInput,
  Purchase
>;

/**
 * @group Operations
 * @category Inputs
 */
export type LoadPurchaseInput = {
  lazyPurchase: LazyPurchase;
  loadJsonMetadata?: boolean; // Default: true

  /** The level of commitment desired when querying the blockchain. */
  commitment?: Commitment;
};

/**
 * @group Operations
 * @category Handlers
 */
export const loadPurchaseOperationHandler: OperationHandler<LoadPurchaseOperation> =
  {
    handle: async (
      operation: LoadPurchaseOperation,
      metaplex: Metaplex,
      scope: DisposableScope
    ) => {
      const {
        lazyPurchase,
        loadJsonMetadata = true,
        commitment,
      } = operation.input;

      const asset = await metaplex
        .nfts()
        .findByMetadata({
          metadata: lazyPurchase.metadataAddress,
          tokenOwner: lazyPurchase.buyerAddress,
          commitment,
          loadJsonMetadata,
        })
        .run(scope);
      assertNftOrSftWithToken(asset);

      return {
        ...lazyPurchase,
        lazy: false,
        isPublic: false,
        asset,
        tokens: amount(lazyPurchase.tokens, asset.mint.currency),
      };
    },
  };

==> js-0.17.3-rc.14.tgz: package/src/plugins/auctionHouseModule/operations/loadPurchase.ts <==
import { assertNftOrSftWithToken } from '../../nftModule';
import { LazyPurchase, Purchase } from '../models/Purchase';
import type { Metaplex } from '@/Metaplex';
import {
  amount,
  Operation,
  OperationHandler,
  OperationScope,
  useOperation,
} from '@/types';

// -----------------
// Operation
// -----------------

const Key = 'LoadPurchaseOperation' as const;

/**
 * Transforms a `LazyPurchase` model into a `Purchase` model.
 *
 * ```ts
 * const purchase = await metaplex
 *   .auctionHouse()
 *   .loadPurchase({ lazyPurchase };
 * ```
 *
 * @group Operations
 * @category Constructors
 */
export const loadPurchaseOperation = useOperation<LoadPurchaseOperation>(Key);

/**
 * @group Operations
 * @category Types
 */
export type LoadPurchaseOperation = Operation<
  typeof Key,
  LoadPurchaseInput,
  Purchase
>;

/**
 * @group Operations
 * @category Inputs
 */
export type LoadPurchaseInput = {
  /** The `LazyPurchase` model to transform into the `Purchase`.  */
  lazyPurchase: LazyPurchase;

  /**
   * Whether or not we should fetch the JSON Metadata for the NFT or SFT.
   *
   * @defaultValue `true`
   */
  loadJsonMetadata?: boolean;
};

/**
 * @group Operations
 * @category Handlers
 */
export const loadPurchaseOperationHandler: OperationHandler<LoadPurchaseOperation> =
  {
    handle: async (
      operation: LoadPurchaseOperation,
      metaplex: Metaplex,
      scope: OperationScope
    ) => {
      const { lazyPurchase, loadJsonMetadata = true } = operation.input;
      const asset = await metaplex.nfts().findByMetadata(
        {
          metadata: lazyPurchase.metadataAddress,
          tokenOwner: lazyPurchase.buyerAddress,
          loadJsonMetadata,
        },
        scope
      );
      assertNftOrSftWithToken(asset);

      return {
        ...lazyPurchase,
        lazy: false,
        isPublic: false,
        asset,
        tokens: amount(lazyPurchase.tokens, asset.mint.currency),
      };
    },
  };
